@@ -7,14 +7,18 @@ class conversion:
     def __init__(self, filename):
         """
 
-        :param output_list:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
         """
         self.file = filename
 
     def convert(self):
         """
 
-        :return:
+        Returns
+        -------
+        Converts a single page pdf file to image and proceeds to process further.
         """
         if self.file[-3::].upper() == "PDF":
             pages = convert_from_path(self.file, 500)
