@@ -1,17 +1,24 @@
+import os
 import docx2txt
-import pandas as pd
 import xlrd
 import csv
 import cv2
 import pytesseract
 from PIL import Image
+from pkgutil import find_loader
 import PyPDF2
 import pdfplumber
 from pptx import Presentation
 from pdf2image import convert_from_path
+import speech_recognition as sr
+
 from pyostie.convert import *
 from pyostie.insights_ext import *
 
+pandas_installed = find_loader("pandas") is not None
+if pandas_installed:
+    import pandas as pd
+
 a = pd.DataFrame()
 ocr_dict_output = []
 
@@ -21,14 +28,18 @@ class DOCXParser:
     def __init__(self, filename):
         """
 
-        :param filename:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
         """
         self.file = filename
 
     def extract_docx(self):
         """
 
-        :return:
+        Returns
+        -------
+        DOCXParser for Docx files.
         """
         output = docx2txt.process(self.file)
         return output
@@ -39,14 +50,18 @@ class XLSXParser:
     def __init__(self, filename):
         """
 
-        :param filename:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
         """
         self.file = filename
 
     def extract_xlsx(self):
         """
 
-        :return:
+        Returns
+        -------
+        XLSXParser for XLSX and XLS files.
         """
         out_list = []
         book = xlrd.open_workbook(self.file)
@@ -60,10 +75,14 @@ class XLSXParser:
 
 class CSVParser:
 
-    def __init__(self, filename, delimiter=','):
+    def __init__(self, filename, delimiter):
         """
 
-        :param filename:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
+        delimiter : By default ','. Can be changed if any other delimiter is needed.
+
         """
         self.file = filename
         self.delimiter = delimiter
@@ -71,7 +90,10 @@ class CSVParser:
     def extract_csv(self):
         """
 
-        :return:
+        Returns
+        -------
+        CSVParser for csv files.
+
         """
         with open(self.file) as file:
             output = csv.reader(file, delimiter=self.delimiter)
@@ -83,8 +105,10 @@ class ImageParser:
     def __init__(self, filename, tess_path=None):
         """
 
-        :param filename:
-        :param tess_path
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
+        tess_path : The path to the tesseract cmd (Only for windows.)
         """
         self.file = filename
         self.path = tess_path
@@ -92,7 +116,10 @@ class ImageParser:
     def extract_image(self):
         """
 
-        :return:
+        Returns
+        -------
+        ImageParser for Image formats.
+
         """
         out_list = []
         if self.path is not None:
@@ -108,15 +135,14 @@ class ImageParser:
 
 
 class PDFParser:
-    """
-
-    """
 
     def __init__(self, filename, insights=False):
         """
 
-        :param filename:
-        :param insights:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
+        insights : True by default. False if the dataframe is not needed.
         """
         self.file = filename
         self.insights = insights
@@ -124,10 +150,11 @@ class PDFParser:
     def extract_pypdf2(self):
         """
 
-        :param kwargs:
-        :return:
-        """
+        Returns
+        -------
+        PDFParser for pdf files.
 
+        """
         contents = []
         text = ' '
         pdfFileObj = open(self.file, 'rb')
@@ -159,6 +186,8 @@ class PDFParser:
                 pdffile = self.file
                 os.mkdir("tempdir")
                 tempdir = "tempdir/"
+                if os.path.isdir(tempdir):
+                    shutil.rmtree(tempdir)
                 os.mkdir("tempdir/converted_files")
                 images = convert_from_path(pdffile)
                 converted_files = tempdir + "converted_files/"
@@ -172,7 +201,7 @@ class PDFParser:
                     page = [val] * len(__insights)
                     __insights["page_num"] = page
                     df_list.append(__insights)
-                pdf_multipage_df = pd.concat([pdf_multipage_df, df_list])
+                    pdf_multipage_df = pd.concat([pdf_multipage_df, __insights])
                 shutil.rmtree(tempdir)
                 df1 = pdf_multipage_df.reset_index()
                 df1 = df1.drop("index", 1)
@@ -183,7 +212,9 @@ class PDFParser:
     def extract_pdfplumber(self):
         """
 
-        :return:
+        Returns
+        -------
+        Works as an alternative for PyPDF2.
         """
         out_list = []
         with pdfplumber.open(self.file) as pdf:
@@ -199,14 +230,18 @@ class TXTParser:
     def __init__(self, filename):
         """
 
-        :param filename:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
         """
         self.file = filename
 
     def extract_txt(self):
         """
 
-        :return:
+        Returns
+        -------
+        TXTParser for txt, log or no extension files.
         """
         with open(self.file) as file:
             return file.read()
@@ -217,13 +252,18 @@ class PPTXParser:
     def __init__(self, filename):
         """
 
-        :param filename:
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
         """
         self.file = filename
 
     def extract_pptx(self):
         """
-        :return:
+
+        Returns
+        -------
+        PPTXParser for pptx files.
         """
         text = []
         paper = Presentation(self.file)
@@ -236,3 +276,33 @@ class PPTXParser:
                     if stripped:
                         text.append(paragraph.text)
         return text
+
+
+class speech_to_text:
+
+    def __init__(self, filename):
+        """
+
+        Parameters
+        ----------
+        filename : The file that needs to be processed.
+        """
+        self.file = filename
+
+    def extract_audio(self):
+        """
+
+        Returns
+        -------
+        speech_to_text for mp3, wav files.
+        """
+        output_audio = []
+        os.mkdir("tempdir")
+        dst_file = mp3_to_wav(self.file, "tempdir/sample.wav", format="wav")
+        output = sr.AudioFile(dst_file)
+        recog = sr.Recognizer()
+        with output as source:
+            audio = recog.record(source)
+        output_audio.append(recog.recognize_google(audio))
+        shutil.rmtree("tempdir")
+        return output_audio
